==> jaxb2-rich-contract-plugin-2.1.0-sources.jar: com/kscs/util/jaxb/bindings/Interface.java <==
//
// Diese Datei wurde mit der JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.11 generiert 
// Siehe <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
// Generiert: 2020.12.15 um 09:23:54 AM CET 
//


package com.kscs.util.jaxb.bindings;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java-Klasse für anonymous complex type.
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="ref" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="declareSetters" type="{http://www.w3.org/2001/XMLSchema}boolean" /&gt;
 *       &lt;attribute name="declareBuilderInterface" type="{http://www.w3.org/2001/XMLSchema}boolean" /&gt;
 *       &lt;attribute name="supportInterfaceNameSuffix" type="{http://www.w3.org/2001/XMLSchema}NCName" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "interface")
public class Interface {

    @XmlAttribute(name = "ref")
    protected String ref;
    @XmlAttribute(name = "declareSetters")
    protected Boolean declareSetters;
    @XmlAttribute(name = "declareBuilderInterface")
    protected Boolean declareBuilderInterface;
    @XmlAttribute(name = "supportInterfaceNameSuffix")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlSchemaType(name = "NCName")
    protected String supportInterfaceNameSuffix;

    /**
     * Ruft den Wert der ref-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRef() {
        return ref;
    }

    /**
     * Legt den Wert der ref-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRef(String value) {
        this.ref = value;
    }

    /**
     * Ruft den Wert der declareSetters-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isDeclareSetters() {
        return declareSetters;
    }

    /**
     * Legt den Wert der declareSetters-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setDeclareSetters(Boolean value) {
        this.declareSetters = value;
    }

    /**
     * Ruft den Wert der declareBuilderInterface-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isDeclareBuilderInterface() {
        return declareBuilderInterface;
    }

    /**
     * Legt den Wert der declareBuilderInterface-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setDeclareBuilderInterface(Boolean value) {
        this.declareBuilderInterface = value;
    }

    /**
     * Ruft den Wert der supportInterfaceNameSuffix-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSupportInterfaceNameSuffix() {
        return supportInterfaceNameSuffix;
    }

    /**
     * Legt den Wert der supportInterfaceNameSuffix-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSupportInterfaceNameSuffix(String value) {
        this.supportInterfaceNameSuffix = value;
    }

}

==> jaxb2-rich-contract-plugin-4.1.0-sources.jar: com/kscs/util/jaxb/bindings/Interface.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.2 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package com.kscs.util.jaxb.bindings;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java-Klasse für anonymous complex type.
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="ref" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="declareSetters" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="declareBuilderInterface" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="supportInterfaceNameSuffix" type="{http://www.w3.org/2001/XMLSchema}NCName" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "interface")
public class Interface {

    @XmlAttribute(name = "ref")
    protected String ref;
    @XmlAttribute(name = "declareSetters")
    protected Boolean declareSetters;
    @XmlAttribute(name = "declareBuilderInterface")
    protected Boolean declareBuilderInterface;
    @XmlAttribute(name = "supportInterfaceNameSuffix")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlSchemaType(name = "NCName")
    protected String supportInterfaceNameSuffix;

    /**
     * Ruft den Wert der ref-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRef() {
        return ref;
    }

    /**
     * Legt den Wert der ref-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRef(String value) {
        this.ref = value;
    }

    /**
     * Ruft den Wert der declareSetters-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isDeclareSetters() {
        return declareSetters;
    }

    /**
     * Legt den Wert der declareSetters-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setDeclareSetters(Boolean value) {
        this.declareSetters = value;
    }

    /**
     * Ruft den Wert der declareBuilderInterface-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isDeclareBuilderInterface() {
        return declareBuilderInterface;
    }

    /**
     * Legt den Wert der declareBuilderInterface-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setDeclareBuilderInterface(Boolean value) {
        this.declareBuilderInterface = value;
    }

    /**
     * Ruft den Wert der supportInterfaceNameSuffix-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSupportInterfaceNameSuffix() {
        return supportInterfaceNameSuffix;
    }

    /**
     * Legt den Wert der supportInterfaceNameSuffix-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSupportInterfaceNameSuffix(String value) {
        this.supportInterfaceNameSuffix = value;
    }

}
